OncoBayes2: OncoBayes2

OncoBayes2R Documentation

OncoBayes2

Description

Bayesian logistic regression model with optional EXchangeability-NonEXchangeability parameter modelling for flexible borrowing from historical or concurrent data-sources. The safety model can guide dose-escalation decisions for adaptive Oncology phase I dose-escalation trials which involve an arbitrary number of drugs.

Global Options

Option Default Description
OncoBayes2.MC.warmup 1000 MCMC warmup iterations
OncoBayes2.MC.iter 2000 total MCMC iterations
OncoBayes2.MC.save_warmup TRUE save warmup samples
OncoBayes2.MC.chains 4 MCMC chains
OncoBayes2.MC.thin 1 MCMC thinning
OncoBayes2.MC.control ⁠list(adapt_delta=0.99,⁠ sets control argument for Stan call
stepsize=0.1)
OncoBayes2.MC.backend rstan Backend used to run Stan (rstan or cmdstanr)
OncoBayes2.abbreviate.min 0 Minimal length of variable names
when abbreviating variable names.
The default 0 disables abbreviation.

Author(s)

Maintainer: Sebastian Weber sebastian.weber@novartis.com

Authors:

Other contributors:

  • Novartis Pharma AG [copyright holder]

  • Trustees of Columbia University (R/stanmodels.R, configure, configure.win) [copyright holder]

References

\insertRef

neuenschwander2016codataOncoBayes2

\insertRef

neuenschwander2016exnexOncoBayes2

\insertRef

neuenschwander2008OncoBayes2

\insertRef

neuenschwander2014OncoBayes2

Stan Development Team (2024). RStan: the R interface to Stan. R package version 2.32.6. https://mc-stan.org

See Also

Useful links:


OncoBayes2 documentation built on Aug. 5, 2026, 1:08 a.m.