powered by
blrm_formula_saturating is a convenience function for generating a formula for blrm_trial and blrm_exnex with an interaction of the form:
blrm_formula_saturating
blrm_trial
blrm_exnex
$$2 \eta \, \frac{\prod_{i=1}^N (d_i \big / d_i^*)}{1 + \prod_{i=1}^N (d_i \big / d_i^*)}$$
blrm_formula_saturating( ref_doses, max_interaction_level = 2, specific_interaction_terms = NULL )
The function returns an object of class blrm_formula.
blrm_formula
Numeric vector of reference doses with names corresponding to drug names
Highest interaction order to consider \([1 - Inf]\). Default: 2
List of custom interaction terms to generate (e.g. list(c("drug1", "drug2"), c("drug1", "drug3"))).
list(c("drug1", "drug2"), c("drug1", "drug3"))
widmer2023OncoBayes2
ref_doses <- c(drug_A = 10, drug_B = 20) # can be used with blrm_trial blrm_formula_saturating(ref_doses)
Run the code above in your browser using DataLab