dot-get_strata_group_fct: extracts from a blrmfit object and a given data-set the group...

.get_strata_group_fctR Documentation

extracts from a blrmfit object and a given data-set the group and stratum factor

Description

extracts from a blrmfit object and a given data-set the group and stratum factor

Usage

.get_strata_group_fct(object, data)

OncoBayes2 documentation built on Aug. 5, 2026, 1:08 a.m.