| OncoBayes2 | R Documentation |
Bayesian logistic regression model with optional EXchangeability-NonEXchangeability parameter modelling for flexible borrowing from historical or concurrent data-sources. The safety model can guide dose-escalation decisions for adaptive Oncology phase I dose-escalation trials which involve an arbitrary number of drugs.
| Option | Default | Description |
OncoBayes2.MC.warmup | 1000 | MCMC warmup iterations |
OncoBayes2.MC.iter | 2000 | total MCMC iterations |
OncoBayes2.MC.save_warmup | TRUE | save warmup samples |
OncoBayes2.MC.chains | 4 | MCMC chains |
OncoBayes2.MC.thin | 1 | MCMC thinning |
OncoBayes2.MC.control | list(adapt_delta=0.99, | sets control argument for Stan call |
stepsize=0.1) | ||
OncoBayes2.MC.backend | rstan | Backend used to run Stan (rstan or cmdstanr) |
OncoBayes2.abbreviate.min | 0 | Minimal length of variable names |
| when abbreviating variable names. | ||
| The default 0 disables abbreviation. | ||
Maintainer: Sebastian Weber sebastian.weber@novartis.com
Authors:
Sebastian Weber sebastian.weber@novartis.com
Lukas A. Widmer lukas_andreas.widmer@novartis.com
Andrew Bean andrew.bean@novartis.com
Other contributors:
Novartis Pharma AG [copyright holder]
Trustees of Columbia University (R/stanmodels.R, configure, configure.win) [copyright holder]
neuenschwander2016codataOncoBayes2
\insertRefneuenschwander2016exnexOncoBayes2
\insertRefneuenschwander2008OncoBayes2
\insertRefneuenschwander2014OncoBayes2
Stan Development Team (2024). RStan: the R interface to Stan. R package version 2.32.6. https://mc-stan.org
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.